Welcome to Spox's documentation!
===================================

Spox is a Python framework for constructing `ONNX <https://github.com/onnx/onnx/>`_ computational graphs.

- The `manual` serves as a technical explanation of Spox, describing various features.
- The `guides` serve as a collection of practical examples in the form of Jupyter notebooks.
- Lastly, the generated `API listing` allows quick access to documentation of public functions.

.. toctree::
   :maxdepth: 2
   :caption: Manual

   manual/overview
   manual/operators
   manual/unstable

.. toctree::
   :maxdepth: 2
   :caption: Guides

   guides/tutorial
   guides/inline
   guides/inference
   guides/converter
   guides/advanced

.. toctree::
   :maxdepth: 1
   :caption: API Listing

   API Reference <api/modules>
   Operator constructors for the ai.onnx domain version 17 <api/spox.opset.ai.onnx.v17>
   Operator constructors for the ai.onnx domain version 18 <api/spox.opset.ai.onnx.v18>
   Operator constructors for the ai.onnx domain version 19 <api/spox.opset.ai.onnx.v19>
   Operator constructors for the ai.onnx domain version 20 <api/spox.opset.ai.onnx.v20>
   Operator constructors for the ai.onnx domain version 21 <api/spox.opset.ai.onnx.v21>
   Operator constructors for the ai.onnx domain version 22 <api/spox.opset.ai.onnx.v22>
   Operator constructors for the ai.onnx domain version 23 <api/spox.opset.ai.onnx.v23>
   Operator constructors for the ai.onnx domain version 24 <api/spox.opset.ai.onnx.v24>
   Operator constructors for the ai.onnx.ml domain version 3 <api/spox.opset.ai.onnx.ml.v3>
   Operator constructors for the ai.onnx.ml domain version 4 <api/spox.opset.ai.onnx.ml.v4>
   Operator constructors for the ai.onnx.ml domain version 5 <api/spox.opset.ai.onnx.ml.v5>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
